@@ -337,9 +337,7 @@ osso_return_t execute(osso_context_t *osso,
     //ignored
   }
   gtk_widget_destroy(GTK_WIDGET(app_data->main_dialog));
-  g_warning("unref soundplayer\n");
   gst_object_unref(app_data->sound_player);
-  g_warning("unref list store\n");
   gst_object_unref(app_data->profiles_list_store);
   g_free(app_data);
   return OSSO_OK;
