@@ -20,6 +20,7 @@
 #define PROFILESX_CONTROL_PANEL_PLUGIN_H
 #include <gtk/gtk.h>
 #include <gst/gst.h>
+#include <gdk/gdkx.h>
 
 typedef struct _user_data_t user_data_t;
 
@@ -34,4 +35,8 @@ struct _user_data_t
 
 void fill_profiles_list_store(user_data_t* data);
 
+void
+profilesx_dialog_size_changed(GdkScreen* screen,
+			      gpointer user_data);
+
 #endif
