@@ -90,7 +90,7 @@ store_icon_name(const gchar* profile_name, const gchar* icon_name)
     g_key_file_remove_key(key_file, profile_name, "icon", NULL);
     gchar* escaped_profile_name = gconf_escape_key(profile_name, -1);
     gchar* old_icon_name = g_strdup_printf("%s.png", escaped_profile_name);
-    gchar* new_icon_path = g_build_filename("/home/user/.profiled/", old_icon_name);
+    gchar* new_icon_path = g_build_filename("/home/user/.profiled/", old_icon_name, NULL);
     if(g_file_test(new_icon_path, G_FILE_TEST_EXISTS))
       g_unlink(new_icon_path);
 
