@@ -24,7 +24,7 @@
 #include "profilesx-profile-data.h"
 
 typedef struct _editor_data_t editor_data_t;
-gchar* get_profile_display_name(const gchar* profile_name);
+const gchar* get_profile_display_name(const gchar* profile_name);
 void show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement* sound_player);
 
 #endif
