@@ -25,7 +25,7 @@
 
 typedef struct _pdata pdata;
 
-void show_progress_bar(gchar* profile_name, 
+void show_progress_bar(const gchar* profile_name, 
 		       user_data_t* data, 
 		       gboolean for_new,
 		       GtkWidget* widget);
