@@ -111,6 +111,27 @@ profilesx_status_plugin_class_finalize(ProfilesxStatusPluginClass* klass)
 {
 }
 
+static void
+profilesx_dialog_size_changed(GdkScreen* screen,
+			      gpointer user_data)
+{
+  GdkGeometry geometry;
+  if(gdk_screen_get_width(gdk_display_get_default_screen(gdk_display_get_default())) < 800)
+  {
+    geometry.min_height = 680;
+    geometry.min_width = 480; 
+  }
+  else
+  {
+    geometry.min_height = 360;
+    geometry.min_width = 800; 
+  }
+  gtk_window_set_geometry_hints(GTK_WINDOW(user_data),
+				GTK_WIDGET(user_data),
+				&geometry,
+				GDK_HINT_MIN_SIZE);
+}
+
 static void
 show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
 {
@@ -174,6 +195,14 @@ show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
 
   hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area); 
   gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))), pannable_area);
+
+  profilesx_dialog_size_changed(gdk_display_get_default_screen(gdk_display_get_default()),
+				dialog);
+
+  g_signal_connect(gdk_display_get_default_screen(gdk_display_get_default()), 
+		   "size-changed", 
+		   G_CALLBACK(profilesx_dialog_size_changed), dialog); 
+
   gtk_widget_show_all(dialog);
 
   int ret = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -199,8 +228,7 @@ show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
     }
   }
   profile_free_profiles(profileList);
-  g_free(vibs);  
-
+  g_free(vibs);
   gtk_widget_destroy(dialog);
 }
 
